@@ -32,6 +32,10 @@ from aiokeydb.core import (
     bool_ok,
 )
 
+# Add top level asyncio module imports
+from aiokeydb.asyncio.lock import AsyncLock
+from aiokeydb.asyncio.core import AsyncKeyDB, AsyncPubSub, AsyncPipeline
+
 from aiokeydb.client.serializers import SerializerType, BaseSerializer
 from aiokeydb.client.config import KeyDBSettings
 from aiokeydb.client.schemas.session import KeyDBSession
